starcluster

Package starcluster |
[hide private]
[frames] | no frames]

# Source Code for Package starcluster

     1  import sys
     2  from starcluster import static
     3  sys.path.insert(0, static.STARCLUSTER_PLUGIN_DIR)
     4
     5  __version__ = static.VERSION
     6  __author__ = "Justin Riley (justin.t.riley@gmail.com)"
     7  __all__ = [
     8      "config",
     9      "static",
    10      "cluster",
    11      "clustersetup",
    12      "node",
    13      "ssh",
    14      "scp",
    15      "plugins",
    16      "balancers",
    17      "managers",
    18      "image",
    19      "volume",
    20      "awsutils",
    21      "cli",
    22      "commands",
    23      "logger",
    24      "utils",
    25      "iptools",
    26      "webtools",
    27      "threadpool",
    28      "templates",
    29      "exception",
    30      "tests",
    31      "optcomplete",
    32      "progressbar",
    33      "spinner",
    34  ]
    35
    36
    37 -def test():
    38      try:
    39          from nose.core import TestProgram
    40          TestProgram(argv=[__file__, "starcluster.tests", '-s'], exit=False)
    41      except ImportError:
    42          print 'error importing nose'
    43
    44  test.__test__ = False
    45